@@ -1,8 +1,7 @@
 package Javonet::Core::AbstractHandler;
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Moose;
-use lib 'lib';
 
 sub handle_command {
 
