@@ -1,12 +1,10 @@
 package Javonet::Core::Handler::CommandHandler::ArrayGetItemHandler;
-use aliased 'Javonet::Core::Handler::PerlHandler' => 'PerlHandler';
 use strict;
 use warnings FATAL => 'all';
-use Moose;
 use lib 'lib';
-use lib 'data_seed';
+use Moose;
 use Nice::Try;
-use aliased 'Javonet::Core::Handler::Exception' => 'Exception';
+use aliased 'Javonet::Core::Exception::Exception' => 'Exception';
 extends 'Javonet::Core::Handler::CommandHandler::AbstractCommandHandler';
 
 sub new {
@@ -32,7 +30,7 @@ sub process {
         return @{$array}[@indexes];
     }
     catch ( $e ) {
-        return $e;
+        return Exception->new($e);
     }
 }
 
